# newpackage

### Install newpackage from PyPi.
```bash
pip install newpackage
```

#### Example
```python
    # Import library
    from newpackage.newpackage import Newpackage
    from newpackage.seconpackage import Newsito
    from newpackage.thirdpackage import Newnewsito

    # Initialize & run functions
    model = Newpackage('Daniel')
    model.use_logger()
    model.show()

    Newsito("Hello World")

    Newnewsito()

```